{% extends '../base_quick.html' %}
{% load static %}
<!-- 结构 -->
{% block structure %}{{ block.super }}<!--     ui/base -->
{% endblock %}

{% block style %}{{ block.super }}
  <!-- 💙 ui/base -->
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@5.2.1/dist/css/swiper.min.css">
  <link rel="stylesheet" href="https://res.wx.qq.com/open/libs/weui/2.1.3/weui.min.css">
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@5.11.2/css/all.min.css">
  <link rel="stylesheet" href="{% static 'css/styles.css' %}">
  <!-- 💛 自定义 style -->{% endblock %}

{% block body %}
  <!-- app bar 区域 -->
{#  <!-- drawer 区域 -->{% block drawer %}<!-- 无侧导航栏 -->{% endblock %}#}
  <!-- main 区域 -->
  <main id="content"{{ dataset_endpoint|safe }}>
    {% block content %}{% endblock %}
  </main>
{% endblock %}

{% block script %}{{ block.super }}<!-- 💙 ui/base -->
  <script src="https://cdn.jsdelivr.net/npm/swiper@5.2.1/dist/js/swiper.min.js"></script>
  <script src="https://res.wx.qq.com/open/libs/weuijs/1.2.1/weui.min.js"></script>
  <script src="https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@5.11.2/js/fontawesome.min.js"></script>
  <script src="{% static 'railguns/es2015/components/weui-components.js' %}"></script>{% endblock %}
